@@ -7,6 +7,7 @@ class ReqIFSpecRelation:  # pylint: disable=too-many-instance-attributes
     def __init__(  # pylint: disable=too-many-arguments
         self,
         children_tags: List[str],
+        xml_node,
         description: Optional[str],
         identifier: str,
         last_change: Optional[str],
@@ -16,6 +17,7 @@ class ReqIFSpecRelation:  # pylint: disable=too-many-instance-attributes
         values_attribute: Optional[SpecObjectAttribute],
     ):
         self.children_tags: List[str] = children_tags
+        self.xml_node = xml_node
         self.description: Optional[str] = description
         self.identifier: str = identifier
         self.last_change: Optional[str] = last_change
